@@ -22,7 +22,10 @@ class EHentaiItem:
             self.url = glink.parent("div").parent("a").attr("href")
         else:
             self.url = glink.parent("a").attr("href")
-        self.thumbnail = data.find("img").attr("src")
+        thumbnail = data.find(".glthumb img")
+        self.thumbnail = thumbnail.attr("src")
+        if not self.thumbnail.startswith("http"):
+            self.thumbnail = thumbnail.attr("data-src")
         self.type = data.find(".cn").eq(0).text()
         self.date = data.find("[id^='posted']").eq(0).text()
         self.tags = [
